@@ -9,6 +9,7 @@ import base64
 from collections import namedtuple
 from datetime import datetime
 import io
+import glob
 import os
 from pathlib import Path
 import re
@@ -56,7 +57,7 @@ def parse_command_line():
     from argparse import ArgumentParser
     parser = ArgumentParser(description='Command-line utility to quickly plot files in a Jupyter notebook.')
 
-    parser.add_argument("files_to_plot", nargs="+", type=Path,
+    parser.add_argument("files_to_plot", nargs="*", type=Path,
                         help="Files to plot. Use '-' for stdin, 'paste-image' for images in the clipboard.")
 
     parser.add_argument("--output", "-o", type=str, default=None,
@@ -174,7 +175,10 @@ def load_source_code_from_notebooks(args):
         except Exception as e:
             error(f"could not create {user_config_path}.")
 
-    for nbpath in sorted(user_templates_path.glob('**/*.ipynb')):
+    # Using glob.glob and not pathlib.glob because of a bug that makes the latter not follow
+    # symlinks.
+    for nbpath in sorted(glob.glob(os.path.join(user_templates_path, '**/*.ipynb'), recursive=True)):
+        nbpath = Path(nbpath)
         info(f'Loading {nbpath}...')
         load_notebook(nbpath)
 
@@ -287,7 +291,7 @@ def get_output_notebook_filepath(args):
         ipynb_dir = shared.config['generated_plots_directory']
         if not ipynb_dir.exists():
             os.makedirs(ipynb_dir)
-        first_file_stem = args.files_to_plot[0].stem
+        first_file_stem = args.files_to_plot[0].stem if args.files_to_plot else "empty"
         if first_file_stem == '-':
             first_file_stem = 'stdin'
         date_str = datetime.now().strftime("%Y-%m-%d_%H-%M-%S")
@@ -355,6 +359,9 @@ def main():
         template = args.template
     print(f'Chosen template: {template}')
 
+    if not args.files_to_plot and not ask_confirmation("No input files provided, create an empty notebook"):
+        sys.exit(0)
+
     nb = generate_notebook(args, template)
 
     output_nb = get_output_notebook_filepath(args)
